<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'gɔ wěkpaxwé ná',
	'diff_para_deplace' => 'sɛ wěkpaxwé sín',
	'diff_para_supprime' => 'súnsún wěkpaxwé sín',
	'diff_texte_ajoute' => 'zě wé gɔ ná',
	'diff_texte_deplace' => 'sɛ wě sín',
	'diff_texte_supprime' => 'súnsún wě sín',

	// I
	'info_historique' => 'sɔ tó fí:',
	'info_historique_lien' => 'mi zé ɖìdyɔ sín àfɔ ɖìɖè xlɛ',
	'info_historique_titre' => 'mi zé ɖìdyɔ sín àfɔ ɖìɖè xlɛ',

	// V
	'version_initiale' => 'wàlɔ bìbɛ tɔn',
];
